<?php
namespace App\Controller;

use App\Controller\AppController;

/**
 * Pruebas Controller
 *
 * @property \App\Model\Table\PruebasTable $Pruebas
 */
class PruebasController extends AppController
{

    /**
     * Index method
     *
     * @return \Cake\Network\Response|null
     */
    public function index()
    {
        $pruebas = $this->paginate($this->Pruebas);

        $this->set(compact('pruebas'));
        $this->set('_serialize', ['pruebas']);
    }

    /**
     * View method
     *
     * @param string|null $id Prueba id.
     * @return \Cake\Network\Response|null
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $prueba = $this->Pruebas->get($id, [
            'contain' => []
        ]);

        $this->set('prueba', $prueba);
        $this->set('_serialize', ['prueba']);
    }

    /**
     * Add method
     *
     * @return \Cake\Network\Response|null Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $prueba = $this->Pruebas->newEntity();
        if ($this->request->is('post')) {
            $prueba = $this->Pruebas->patchEntity($prueba, $this->request->data);
            if ($this->Pruebas->save($prueba)) {
                $this->Flash->success(__('The prueba has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The prueba could not be saved. Please, try again.'));
        }
        $this->set(compact('prueba'));
        $this->set('_serialize', ['prueba']);
    }

    /**
     * Edit method
     *
     * @param string|null $id Prueba id.
     * @return \Cake\Network\Response|null Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $prueba = $this->Pruebas->get($id, [
            'contain' => []
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $prueba = $this->Pruebas->patchEntity($prueba, $this->request->data);
            if ($this->Pruebas->save($prueba)) {
                $this->Flash->success(__('The prueba has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The prueba could not be saved. Please, try again.'));
        }
        $this->set(compact('prueba'));
        $this->set('_serialize', ['prueba']);
    }

    /**
     * Delete method
     *
     * @param string|null $id Prueba id.
     * @return \Cake\Network\Response|null Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $prueba = $this->Pruebas->get($id);
        if ($this->Pruebas->delete($prueba)) {
            $this->Flash->success(__('The prueba has been deleted.'));
        } else {
            $this->Flash->error(__('The prueba could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
  
  public function search()
	{
		$search = null;
		if(!empty($this->request->query['search']))
		{
			$search = $this->request->query['search'];
			$search = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 ]/', '', $search);
			$terms = explode(' ', trim($search));
			$terms = array_diff($terms, array(''));
			
			foreach($terms as $term)
			{
				$terms1[] = preg_replace('/[^a-zA-ZñÑáéíóúÁÉÍÓÚ0-9 ]/', '', $term);
				$conditions[] = array('Pruebas.detalle LIKE' => '%' . $term . '%');
			}
			$pruebas = $this->Pruebas->find('all', array('recursive' => -1, 'conditions' => $conditions, 'limit' => 200));
			if(count($pruebas) > 1)
			{
				foreach ($pruebas as $prueba){
					return $this->redirect(array('controller' => 'pruebas', 'action' => 'view', $prueba->id));
				}
			} else {
            $this->Flash->error(__('Ningun resultado. Please, try again.'));
        }
			$terms1 = array_diff($terms1, array(''));
			$this->set(compact('pruebas', 'terms1'));
		}
		$this->set(compact('search'));
		
		if($this->request->is('ajax'))
		{
			$this->layout = false;
			$this->set('ajax', 1);
		}
		else
		{
			$this->set('ajax', 0);
		}
	}
}
