<?php
namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Cambioprecios Model
 *
 * @property \App\Model\Table\StocksTable|\Cake\ORM\Association\BelongsTo $Stocks
 *
 * @method \App\Model\Entity\Cambioprecio get($primaryKey, $options = [])
 * @method \App\Model\Entity\Cambioprecio newEntity($data = null, array $options = [])
 * @method \App\Model\Entity\Cambioprecio[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\Cambioprecio|bool save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Cambioprecio|bool saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Cambioprecio patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\Cambioprecio[] patchEntities($entities, array $data, array $options = [])
 * @method \App\Model\Entity\Cambioprecio findOrCreate($search, callable $callback = null, $options = [])
 */
class CambiopreciosTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->setTable('cambioprecios');
        $this->setDisplayField('descripcion');
        $this->setPrimaryKey('id');

        $this->belongsTo('Stocks', [
            'foreignKey' => 'stock_id'
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator)
    {
        $validator
            ->integer('id')
            ->allowEmpty('id', 'create');

        $validator
            ->scalar('chasis')
            ->maxLength('chasis', 250)
            ->allowEmpty('chasis');

        $validator
            ->numeric('entregaminima')
            ->allowEmpty('entregaminima');

        $validator
            ->numeric('contado')
            ->allowEmpty('contado');

        $validator
            ->numeric('contado3meses')
            ->allowEmpty('contado3meses');

        $validator
            ->numeric('meses12')
            ->allowEmpty('meses12');

        $validator
            ->numeric('meses18')
            ->allowEmpty('meses18');

        $validator
            ->scalar('fecha')
            ->maxLength('fecha', 250)
            ->allowEmpty('fecha');

        $validator
            ->integer('estado')
            ->allowEmpty('estado');

        $validator
            ->integer('precioautomatico')
            ->notEmpty('precioautomatico', 'Seleccione una opción');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules)
    {
        $rules->add($rules->existsIn(['stock_id'], 'Stocks'));

        return $rules;
    }
}
