<?php
namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Inventarios Model
 *
 * @property \Cake\ORM\Association\BelongsTo $Trabajadors
 *
 * @method \App\Model\Entity\Inventario get($primaryKey, $options = [])
 * @method \App\Model\Entity\Inventario newEntity($data = null, array $options = [])
 * @method \App\Model\Entity\Inventario[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\Inventario|bool save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Inventario|bool saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Inventario patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\Inventario[] patchEntities($entities, array $data, array $options = [])
 * @method \App\Model\Entity\Inventario findOrCreate($search, callable $callback = null, $options = [])
 */
class InventariosTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->setTable('inventarios');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->belongsTo('Trabajadors', [
            'foreignKey' => 'tablerista'
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator)
    {
        $validator
            ->integer('id')
            ->notEmpty('id', 'create') ;

        $validator
            ->scalar('fecha')
            ->maxLength('fecha', 250)
            ->requirePresence('fecha', 'create')
            ->notEmpty('fecha');

        $validator
            ->integer('usuario')
            ->notEmpty('usuario');

        $validator
            ->scalar('modelo')
            ->maxLength('modelo', 250)
            ->requirePresence('modelo', 'create')
            ->notEmpty('modelo', 'Rellene este campo');

        $validator
            ->scalar('marca')
            ->maxLength('marca', 250)
            ->requirePresence('marca', 'create')
            ->notEmpty('marca', 'Rellene este campo');

        $validator
            ->scalar('kilometraje')
            ->maxLength('kilometraje', 250)
            ->requirePresence('kilometraje', 'create')
            ->notEmpty('kilometraje', 'Rellene este campo');

        $validator
            ->scalar('color')
            ->maxLength('color', 250)
            ->requirePresence('color', 'create')
            ->notEmpty('color', 'Rellene este campo');

        /*$validator
            ->scalar('chasis')
            ->maxLength('chasis', 250)
            ->requirePresence('chasis', 'create')
            ->notEmpty('chasis', 'Rellene este campo');
            
            */
            
        $validator
            ->scalar('chasis')
            ->minLength('chasis', 8, __('El chasis debe tener al menos 8 caracteres.'))
            ->regex('chasis', '/^[^._\s]+$/')
            ->notEmpty('chasis', __('Por favor ingrese el número de chasis.'))
            ->add('chasis', 'custom', [
                'rule' => function ($value, $context) {
                    // Aquí puedes agregar lógica adicional de validación según tus necesidades
                    // Por ejemplo, verificar si el chasis es mayor a 9 y no contiene puntos, guiones bajos ni espacios
                    return strlen($value) > 7 && !preg_match('/[._]/', $value); // Verifica si el chasis tiene más de 9 caracteres
                },
                'message' => __('El chasis no debe contener puntos, guiones bajos ni espacios.')
            ]);

        $validator
            ->integer('cuentaaceite')
            ->notEmpty('cuentaaceite', 'Seleccione una opción');

        $validator
            ->integer('motorfunciona')
            ->notEmpty('motorfunciona', 'Seleccione una opción');

        $validator
            ->integer('cajafunciona')
            ->notEmpty('cajafunciona', 'Seleccione una opción');

        $validator
            ->integer('chequin')
            ->notEmpty('chequin', 'Seleccione una opción');

        $validator
            ->integer('radiotv')
            ->notEmpty('radiotv', 'Seleccione una opción');

        $validator
            ->integer('insigniatrasera')
            ->notEmpty('insigniatrasera', 'Seleccione una opción');

        $validator
            ->integer('insigniadetalantera')
            ->notEmpty('insigniadetalantera', 'Seleccione una opción');

        $validator
            ->integer('cabeceras')
            ->notEmpty('cabeceras', 'Seleccione una opción');

        $validator
            ->integer('bocina')
            ->notEmpty('bocina', 'Seleccione una opción');

        $validator
            ->integer('aire')
            ->notEmpty('aire', 'Seleccione una opción');

        $validator
            ->integer('bloqueopuerta')
            ->notEmpty('bloqueopuerta', 'Seleccione una opción');

        $validator
            ->integer('tapizados')
            ->notEmpty('tapizados', 'Seleccione una opción');

        $validator
            ->integer('luces')
            ->notEmpty('luces', 'Seleccione una opción');

        $validator
            ->integer('espejos')
            ->notEmpty('espejos', 'Seleccione una opción');

        $validator
            ->integer('herramientas')
            ->notEmpty('herramientas', 'Seleccione una opción');

        $validator
            ->scalar('observacion')
            ->maxLength('observacion', 1000)
            ->allowEmpty('observacion');

        $validator
            ->integer('tablerista')
            ->notEmpty('tablerista', 'Seleccione una opción');

        $validator
            ->integer('tableristaestado')
            ->notEmpty('tableristaestado', 'Seleccione una opción');

        $validator
            ->integer('airista')
            ->notEmpty('airista', 'Seleccione una opción');

        $validator
            ->integer('airistaestado')
            ->notEmpty('airistaestado', 'Seleccione una opción');

        $validator
            ->integer('mecanico')
            ->notEmpty('mecanico', 'Seleccione una opción');

        $validator
            ->integer('mecanicoestado')
            ->notEmpty('mecanicoestado', 'Seleccione una opción');

        $validator
            ->integer('cuentaaceitecv')
            ->notEmpty('cuentaaceitecv', 'Seleccione una opción');

        $validator
            ->integer('motorfuncionacv')
            ->notEmpty('motorfuncionacv', 'Seleccione una opción');

        $validator
            ->integer('cajafuncionacv')
            ->notEmpty('cajafuncionacv', 'Seleccione una opción');

        $validator
            ->integer('chequincv')
            ->notEmpty('chequincv', 'Seleccione una opción');

        $validator
            ->integer('radiotvcv')
            ->notEmpty('radiotvcv', 'Seleccione una opción');

        $validator
            ->integer('insigniatraseracv')
            ->notEmpty('insigniatraseracv', 'Seleccione una opción');

        $validator
            ->integer('insigniadetalanteracv')
            ->notEmpty('insigniadetalanteracv', 'Seleccione una opción');

        $validator
            ->integer('cabecerascv')
            ->notEmpty('cabecerascv', 'Seleccione una opción');

        $validator
            ->integer('bocinacv')
            ->notEmpty('bocinacv', 'Seleccione una opción');

        $validator
            ->integer('airecv')
            ->notEmpty('airecv', 'Seleccione una opción');

        $validator
            ->integer('bloqueopuertacv')
            ->notEmpty('bloqueopuertacv', 'Seleccione una opción');

        $validator
            ->integer('tapizadoscv')
            ->notEmpty('tapizadoscv', 'Seleccione una opción');

        $validator
            ->integer('lucescv')
            ->notEmpty('lucescv', 'Seleccione una opción');

        $validator
            ->integer('espejoscv')
            ->notEmpty('espejoscv', 'Seleccione una opción');

        $validator
            ->integer('herramientascv')
            ->notEmpty('herramientascv', 'Seleccione una opción');

        $validator
            ->scalar('recibidocv')
            ->maxLength('recibidocv', 250)
            ->notEmpty('recibidocv', 'Seleccione una opción');

        $validator
            ->scalar('observacioncv')
            ->maxLength('observacioncv', 500)
            ->allowEmpty('observacioncv');

        $validator
            ->integer('estadocv')
            ->notEmpty('estadocv', 'Seleccione una opción');

        $validator
            ->integer('modificarcv')
            ->notEmpty('modificarcv', 'Seleccione una opción');

        $validator
            ->integer('usuariocv')
            ->notEmpty('usuariocv', 'Seleccione una opción');

        $validator
            ->integer('cuentaaceitechaperia')
            ->notEmpty('cuentaaceitechaperia', 'Seleccione una opción');

        $validator
            ->integer('motorfuncionachaperia')
            ->notEmpty('motorfuncionachaperia', 'Seleccione una opción');

        $validator
            ->integer('cajafuncionachaperia')
            ->notEmpty('cajafuncionachaperia', 'Seleccione una opción');

        $validator
            ->integer('chequinchaperia')
            ->notEmpty('chequinchaperia', 'Seleccione una opción');

        $validator
            ->integer('radiotvchaperia')
            ->notEmpty('radiotvchaperia', 'Seleccione una opción');

        $validator
            ->integer('insigniatraserachaperia')
            ->notEmpty('insigniatraserachaperia', 'Seleccione una opción');

        $validator
            ->integer('insigniadetalanterachaperia')
            ->notEmpty('insigniadetalanterachaperia', 'Seleccione una opción');

        $validator
            ->integer('cabeceraschaperia')
            ->notEmpty('cabeceraschaperia', 'Seleccione una opción');

        $validator
            ->integer('bocinachaperia')
            ->notEmpty('bocinachaperia', 'Seleccione una opción');

        $validator
            ->integer('airechaperia')
            ->notEmpty('airechaperia', 'Seleccione una opción');

        $validator
            ->integer('bloqueopuertachaperia')
            ->notEmpty('bloqueopuertachaperia', 'Seleccione una opción');

        $validator
            ->integer('tapizadoschaperia')
            ->notEmpty('tapizadoschaperia', 'Seleccione una opción');

        $validator
            ->integer('luceschaperia')
            ->notEmpty('luceschaperia', 'Seleccione una opción');

        $validator
            ->integer('espejoschaperia')
            ->notEmpty('espejoschaperia', 'Seleccione una opción');

        $validator
            ->integer('herramientaschaperia')
            ->notEmpty('herramientaschaperia', 'Seleccione una opción');

        $validator
            ->scalar('recibidochaperia')
            ->maxLength('recibidochaperia', 250)
            ->notEmpty('recibidochaperia', 'Seleccione una opción');

        $validator
            ->scalar('observacionchaperia')
            ->maxLength('observacionchaperia', 500)
            ->allowEmpty('observacionchaperia');

        $validator
            ->integer('estadochaperia')
            ->notEmpty('estadochaperia', 'Seleccione una opción');

        $validator
            ->integer('modificarchaperia')
            ->notEmpty('modificarchaperia', 'Seleccione una opción');

        $validator
            ->integer('usuariochaperia')
            ->notEmpty('usuariochaperia', 'Seleccione una opción');

        $validator
            ->integer('cuentaaceiteplaya')
            ->notEmpty('cuentaaceiteplaya', 'Seleccione una opción');

        $validator
            ->integer('motorfuncionaplaya')
            ->notEmpty('motorfuncionaplaya', 'Seleccione una opción');

        $validator
            ->integer('cajafuncionaplaya')
            ->notEmpty('cajafuncionaplaya', 'Seleccione una opción');

        $validator
            ->integer('chequinplaya')
            ->notEmpty('chequinplaya', 'Seleccione una opción');

        $validator
            ->integer('radiotvplaya')
            ->notEmpty('radiotvplaya', 'Seleccione una opción');

        $validator
            ->integer('insigniatraseraplaya')
            ->notEmpty('insigniatraseraplaya', 'Seleccione una opción');

        $validator
            ->integer('insigniadetalanteraplaya')
            ->notEmpty('insigniadetalanteraplaya', 'Seleccione una opción');

        $validator
            ->integer('cabecerasplaya')
            ->notEmpty('cabecerasplaya', 'Seleccione una opción');

        $validator
            ->integer('bocinaplaya')
            ->notEmpty('bocinaplaya', 'Seleccione una opción');

        $validator
            ->integer('aireplaya')
            ->notEmpty('aireplaya', 'Seleccione una opción');

        $validator
            ->integer('bloqueopuertaplaya')
            ->notEmpty('bloqueopuertaplaya', 'Seleccione una opción');

        $validator
            ->integer('tapizadosplaya')
            ->notEmpty('tapizadosplaya', 'Seleccione una opción');

        $validator
            ->integer('lucesplaya')
            ->notEmpty('lucesplaya', 'Seleccione una opción');

        $validator
            ->integer('espejosplaya')
            ->notEmpty('espejosplaya', 'Seleccione una opción');

        $validator
            ->integer('herramientasplaya')
            ->notEmpty('herramientasplaya', 'Seleccione una opción');

        $validator
            ->scalar('recibidoplaya')
            ->maxLength('recibidoplaya', 250)
            ->notEmpty('recibidoplaya', 'Seleccione una opción');

        $validator
            ->scalar('observacionplaya')
            ->maxLength('observacionplaya', 500)
            ->allowEmpty('observacionplaya');

        $validator
            ->integer('estadoplaya')
            ->notEmpty('estadoplaya', 'Seleccione una opción');

        $validator
            ->integer('modificarplaya')
            ->notEmpty('modificarplaya', 'Seleccione una opción');

        $validator
            ->integer('usuarioplaya')
            ->notEmpty('usuarioplaya', 'Seleccione una opción');

        $validator
            ->integer('cuentaaceiteplaya2')
            ->notEmpty('cuentaaceiteplaya2', 'Seleccione una opción');

        $validator
            ->integer('motorfuncionaplaya2')
            ->notEmpty('motorfuncionaplaya2', 'Seleccione una opción');

        $validator
            ->integer('cajafuncionaplaya2')
            ->notEmpty('cajafuncionaplaya2', 'Seleccione una opción');

        $validator
            ->integer('chequinplaya2')
            ->notEmpty('chequinplaya2', 'Seleccione una opción');

        $validator
            ->integer('radiotvplaya2')
            ->notEmpty('radiotvplaya2', 'Seleccione una opción');

        $validator
            ->integer('insigniatraseraplaya2')
            ->notEmpty('insigniatraseraplaya2', 'Seleccione una opción');

        $validator
            ->integer('insigniadetalanteraplaya2')
            ->notEmpty('insigniadetalanteraplaya2', 'Seleccione una opción');

        $validator
            ->integer('cabecerasplaya2')
            ->notEmpty('cabecerasplaya2', 'Seleccione una opción');

        $validator
            ->integer('bocinaplaya2')
            ->notEmpty('bocinaplaya2', 'Seleccione una opción');

        $validator
            ->integer('aireplaya2')
            ->notEmpty('aireplaya2', 'Seleccione una opción');

        $validator
            ->integer('bloqueopuertaplaya2')
            ->notEmpty('bloqueopuertaplaya2', 'Seleccione una opción');

        $validator
            ->integer('tapizadosplaya2')
            ->notEmpty('tapizadosplaya2', 'Seleccione una opción');

        $validator
            ->integer('lucesplaya2')
            ->notEmpty('lucesplaya2', 'Seleccione una opción');

        $validator
            ->integer('espejosplaya2')
            ->notEmpty('espejosplaya2', 'Seleccione una opción');

        $validator
            ->integer('herramientasplaya2')
            ->notEmpty('herramientasplaya2', 'Seleccione una opción');

        $validator
            ->scalar('recibidoplaya2')
            ->maxLength('recibidoplaya2', 250)
            ->notEmpty('recibidoplaya2', 'Seleccione una opción');

        $validator
            ->scalar('observacionplaya2')
            ->maxLength('observacionplaya2', 500)
            ->allowEmpty('observacionplaya2');

        $validator
            ->integer('estadoplaya2')
            ->notEmpty('estadoplaya2', 'Seleccione una opción');

        $validator
            ->integer('modificarplaya2')
            ->notEmpty('modificarplaya2', 'Seleccione una opción');

        $validator
            ->integer('usuarioplaya2')
            ->notEmpty('usuarioplaya2', 'Seleccione una opción');

        $validator
            ->integer('funcionacamara')
            ->notEmpty('funcionacamara', 'Seleccione una opción');

        $validator
            ->integer('traellantadeportiva')
            ->notEmpty('traellantadeportiva', 'Seleccione una opción');

        $validator
            ->integer('traellantaiguales')
            ->notEmpty('traellantaiguales', 'Seleccione una opción');

        $validator
            ->integer('funcionacamaracv')
            ->notEmpty('funcionacamaracv', 'Seleccione una opción');

        $validator
            ->integer('traellantadeportivacv')
            ->notEmpty('traellantadeportivacv', 'Seleccione una opción');

        $validator
            ->integer('traellantaigualescv')
            ->notEmpty('traellantaigualescv', 'Seleccione una opción');

        $validator
            ->integer('funcionacamarachaperia')
            ->notEmpty('funcionacamarachaperia', 'Seleccione una opción');

        $validator
            ->integer('traellantadeportivachaperia')
            ->notEmpty('traellantadeportivachaperia', 'Seleccione una opción');

        $validator
            ->integer('traellantaigualeschaperia')
            ->notEmpty('traellantaigualeschaperia', 'Seleccione una opción');

        $validator
            ->integer('funcionacamaraplaya')
            ->notEmpty('funcionacamaraplaya', 'Seleccione una opción');

        $validator
            ->integer('traellantadeportivaplaya')
            ->notEmpty('traellantadeportivaplaya', 'Seleccione una opción');

        $validator
            ->integer('traellantaigualesplaya')
            ->notEmpty('traellantaigualesplaya', 'Seleccione una opción');

        $validator
            ->integer('funcionacamaraplaya2')
            ->notEmpty('funcionacamaraplaya2', 'Seleccione una opción');

        $validator
            ->integer('traellantadeportivaplaya2')
            ->notEmpty('traellantadeportivaplaya2', 'Seleccione una opción');

        $validator
            ->integer('traellantaigualesplaya2')
            ->notEmpty('traellantaigualesplaya2', 'Seleccione una opción');

        $validator
            ->integer('tienetapallanta')  
            ->notEmpty('tienetapallanta', 'Seleccione una opción'); 

        $validator  
            ->integer('sensordeluz')  
            ->notEmpty('sensordeluz', 'Seleccione una opción');

        $validator  
            ->integer('luzdeguantera')  
            ->notEmpty('luzdeguantera', 'Seleccione una opción');

        $validator  
            ->integer('gomacanodevolante')  
            ->notEmpty('gomacanodevolante', 'Seleccione una opción');

        $validator  
            ->integer('tapatablero')  
            ->notEmpty('tapatablero', 'Seleccione una opción');
        
        $validator  
            ->integer('filtrodeaire')  
            ->notEmpty('filtrodeaire', 'Seleccione una opción');

        $validator  
            ->integer('tienetapallantavc')  
            ->notEmpty('tienetapallantavc', 'Seleccione una opción');

        $validator  
            ->integer('sensordeluzvc')  
            ->notEmpty('sensordeluzvc', 'Seleccione una opción');

        $validator  
            ->integer('luzdeguanteravc')  
            ->notEmpty('luzdeguanteravc', 'Seleccione una opción');

        $validator  
            ->integer('gomacanodevolantevc')  
            ->notEmpty('gomacanodevolantevc', 'Seleccione una opción');

        $validator  
            ->integer('tapatablerovc')  
            ->notEmpty('tapatablerovc', 'Seleccione una opción');

        $validator  
            ->integer('filtrodeairevc')  
            ->notEmpty('filtrodeairevc', 'Seleccione una opción');

        $validator  
            ->integer('tienetapallantachaperia')  
            ->notEmpty('tienetapallantachaperia', 'Seleccione una opción');

        $validator  
            ->integer('sensordeluzchaperia')  
            ->notEmpty('sensordeluzchaperia', 'Seleccione una opción');

        $validator  
            ->integer('luzdeguanterachaperia')  
            ->notEmpty('luzdeguanterachaperia', 'Seleccione una opción');

        $validator  
            ->integer('gomacanodevolantechaperia')  
            ->notEmpty('gomacanodevolantechaperia', 'Seleccione una opción');

        $validator  
            ->integer('tapatablerochaperia')  
            ->notEmpty('tapatablerochaperia', 'Seleccione una opción');

        $validator  
            ->integer('filtrodeairechaperia')  
            ->notEmpty('filtrodeairechaperia', 'Seleccione una opción');

        $validator  
            ->integer('tienetapallantaplaya')  
            ->notEmpty('tienetapallantaplaya', 'Seleccione una opción');

        $validator  
            ->integer('sensordeluzplaya')  
            ->notEmpty('sensordeluzplaya', 'Seleccione una opción');

        $validator  
            ->integer('luzdeguanteraplaya')  
            ->notEmpty('luzdeguanteraplaya', 'Seleccione una opción');

        $validator  
            ->integer('gomacanodevolanteplaya')  
            ->notEmpty('gomacanodevolanteplaya', 'Seleccione una opción');

        $validator  
            ->integer('tapatableroplaya')  
            ->notEmpty('tapatableroplaya', 'Seleccione una opción');

        $validator  
            ->integer('filtrodeaireplaya')  
            ->notEmpty('filtrodeaireplaya', 'Seleccione una opción');

        $validator  
            ->integer('tienetapallantaplaya2')  
            ->notEmpty('tienetapallantaplaya2', 'Seleccione una opción');

        $validator  
            ->integer('sensordeluzplaya2')  
            ->notEmpty('sensordeluzplaya2', 'Seleccione una opción');

        $validator  
            ->integer('luzdeguanteraplaya2')  
            ->notEmpty('luzdeguanteraplaya2', 'Seleccione una opción');

        $validator  
            ->integer('gomacanodevolanteplaya2')  
            ->notEmpty('gomacanodevolanteplaya2', 'Seleccione una opción');

        $validator  
            ->integer('tapatableroplaya2')  
            ->notEmpty('tapatableroplaya2', 'Seleccione una opción');

        $validator  
            ->integer('filtrodeaireplaya2')  
            ->notEmpty('filtrodeaireplaya2', 'Seleccione una opción');

        return $validator;
    }
}
