<?php
namespace App\Controller;

use App\Controller\AppController;

/**
 * Bonos Controller
 *
 * @property \App\Model\Table\BonosTable $Bonos
 *
 * @method \App\Model\Entity\Bono[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class BonosController extends AppController
{

    /**
     * Index method
     *
     * @return \Cake\Http\Response|void
     */
    public function index()
    {
        $this->paginate = [
            'contain' => ['Stocks', 'Empleados']
        ];
        $bonos = $this->paginate($this->Bonos);

        $this->set(compact('bonos'));
    }

    /**
     * View method
     *
     * @param string|null $id Bono id.
     * @return \Cake\Http\Response|void
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $bono = $this->Bonos->get($id, [
            'contain' => ['Stocks', 'Empleados']
        ]);

        $this->set('bono', $bono);
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $bono = $this->Bonos->newEntity();
        if ($this->request->is('post')) {
            $bono = $this->Bonos->patchEntity($bono, $this->request->getData());
            if ($this->Bonos->save($bono)) {
                $this->Flash->success(__('The bono has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The bono could not be saved. Please, try again.'));
        }
        $stocks = $this->Bonos->Stocks->find('list', ['limit' => 200]);
        $empleados = $this->Bonos->Empleados->find('list', ['limit' => 200]);
        $this->set(compact('bono', 'stocks', 'empleados'));
    }

    /**
     * Edit method
     *
     * @param string|null $id Bono id.
     * @return \Cake\Http\Response|null Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $bono = $this->Bonos->get($id, [
            'contain' => []
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $bono = $this->Bonos->patchEntity($bono, $this->request->getData());
            if ($this->Bonos->save($bono)) {
                $this->Flash->success(__('The bono has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The bono could not be saved. Please, try again.'));
        }
        $stocks = $this->Bonos->Stocks->find('list', ['limit' => 200]);
        $empleados = $this->Bonos->Empleados->find('list', ['limit' => 200]);
        $this->set(compact('bono', 'stocks', 'empleados'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Bono id.
     * @return \Cake\Http\Response|null Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $bono = $this->Bonos->get($id);
        if ($this->Bonos->delete($bono)) {
            $this->Flash->success(__('The bono has been deleted.'));
        } else {
            $this->Flash->error(__('The bono could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
}
